import Flat from'flat';import {get,range,keys,kebabCase,map,pick,filter}from'lodash-es';import*as Yaml from'yamljs';import React__default,{useEffect,useMemo,useState}from'react';import {compose}from'redux';import Highlight from'react-highlight';import {Form,Alert,Input,Select,AutoComplete,Button}from'antd';const {
  Item
} = Form;
const {
  Group
} = Input;
const {
  Option
} = Select;
const {
  Option: AOption
} = AutoComplete;
const ChartInstallationComponent = ({
  onInstall,
  chart,
  stack,
  versions,
  values: valuesYAML,
  onChangeVersion,
  readme = null
}) => {
  const [form] = Form.useForm();
  useEffect(() => {
    form.setFieldsValue({
      type: 'MONOCULAR_STACK',
      chartName: get(chart, 'name'),
      repository: get(chart, 'latest_version'),
      variables: valuesYAML ? range(1) : []
    });
  }, []);
  const onSubmit = values => {
    const data = pick(values, ['type', 'chartName', 'repository', 'releaseName', 'chartVersion']);
    data.variables = values(values.env);
    onInstall(data);
  };
  const values = useMemo(() => valuesYAML ? Yaml.parse(valuesYAML) : {}, [valuesYAML]);
  const [showValue, setShowValue] = useState(false);
  const [dataSource, setDataSource] = useState([]);
  useEffect(() => {
    setDataSource(valuesYAML ? keys(Flat(Yaml.parse(valuesYAML))) : []);
  }, []);
  const renderValueSuggestion = item => {
    return React__default.createElement(AOption, {
      key: item,
      title: item,
      value: item
    }, item);
  };
  const searchResult = keyword => {
    const filterArray = filter(keys(Flat(values)), item => item.includes(keyword));
    return filterArray || [];
  };
  const handleSearch = keyword => {
    keyword ? setDataSource(searchResult(keyword)) : setDataSource([]);
  };
  return React__default.createElement("div", {
    className: styles.formContainer
  }, !readme ? React__default.createElement(Alert, {
    message: "Readme not Found!",
    description: "This chart doesn't provide readme",
    type: "warning"
  }) : null, React__default.createElement(Form, {
    onFinish: onSubmit
  }, React__default.createElement(Item, {
    name: 'releaseName',
    label: 'Release name',
    initialValue: chart.name,
    normalize: value => kebabCase(value),
    rules: [{
      required: true,
      message: 'Release name is required'
    }]
  }, React__default.createElement(Input, {
    size: "large",
    type: "text"
  })), React__default.createElement(Item, {
    name: 'chartVersion',
    label: 'Chart version',
    initialValue: chart.latest_version,
    rules: [{
      required: true,
      message: 'Chart version is required'
    }]
  }, React__default.createElement(Select, {
    size: "large",
    onChange: onChangeVersion
  }, map(versions, record => React__default.createElement(Option, {
    key: record.version,
    value: record.version
  }, record.version))), ","), React__default.createElement("div", null, React__default.createElement("h4", null, "Chart values"), map(form.getFieldValue('variables'), (item, index) => React__default.createElement(Group, {
    size: "large",
    compact: true,
    className: "mb-3"
  }, React__default.createElement(Item, {
    name: `env[${item}].field`,
    noStyle: true,
    initialValue: ''
  }, React__default.createElement(AutoComplete, {
    size: "large",
    style: {
      width: '40%'
    },
    dataSource: map(dataSource, renderValueSuggestion),
    onSearch: handleSearch
  })), React__default.createElement(Item, {
    name: `env[${item}].value`,
    noStyle: true,
    initialValue: ''
  }, React__default.createElement(Input, {
    size: "large",
    style: {
      width: '40%'
    }
  })), React__default.createElement(Button, {
    size: "large",
    danger: true,
    className: "m-0",
    style: {
      width: '20%'
    },
    onClick: () => {
      form.setFieldsValue({
        variables: form.getFieldValue('variables').filter(varIndex => varIndex !== item)
      });
    }
  }, "Remove"))), React__default.createElement("div", {
    className: "text-right"
  }, React__default.createElement("a", {
    href: "javascript:void(0)",
    onClick: () => setShowValue(!showValue)
  }, showValue ? 'Hide' : 'View', " values.yml file"), ' | ', React__default.createElement("a", {
    href: "javascript:void(0)",
    onClick: () => {
      form.setFieldsValue({
        variables: form.getFieldValue('variables').concat([Math.random()])
      });
    }
  }, "Add value")), valuesYAML && showValue ? React__default.createElement(Highlight, {
    style: styles.code,
    language: "yaml"
  }, React__default.createElement("pre", null, valuesYAML)) : null), React__default.createElement("div", {
    className: "text-center"
  }, React__default.createElement(Button, {
    size: "large",
    type: "primary",
    className: "m-0",
    onClick: onSubmit
  }, "Submit"))));
};
const styles = {
  code: props => ({
    height: '300px',
    overflowY: 'auto',
    overflowX: 'auto'
  }),
  formContainer: props => ({
    paddingTop: '30px',
    '& form': {
      marginTop: '10px'
    }
  })
};
const ChartInstallation = compose(ChartInstallationComponent);export{ChartInstallation};//# sourceMappingURL=ChartInstallation.js.map
